@@ -78,6 +78,8 @@ def agent_environment_experiment(
     """
     if settings is None:
         settings = {}
+    if initial_state is None:
+        initial_state = {}
 
     # experiment settings
     emitter = settings.get('emitter', {'type': 'timeseries'})
@@ -115,7 +117,7 @@ def agent_environment_experiment(
                     agent_id: initial_agent_state
                     for agent_id in agent_ids})
 
-    if 'agents' in initial_state:
+    if 'agents' in initial_state and 'diffusion' in environment_config['config']:
         environment_config[
             'config']['diffusion']['agents'] = initial_state['agents']
 
@@ -351,7 +353,8 @@ def simulate_experiment(experiment, settings={}):
     return_raw_data = settings.get('return_raw_data', False)
 
     if 'timeline' in settings:
-        total_time = settings['timeline']['timeline'][-1][0]
+        all_times = [t[0] for t in settings['timeline']['timeline']]
+        total_time = max(all_times)
 
     # run simulation
     experiment.update(total_time)
@@ -575,7 +578,10 @@ def plot_simulation_output(timeseries_raw, settings={}, out_dir='out', filename=
 
                 # plot the series
                 ax.plot(time_vec, series)
-                ax.title.set_text(str(port) + ': ' + str(state_id))
+                if isinstance(state_id, tuple):
+                    # new line for each store
+                    state_id = '\n'.join(state_id)
+                ax.title.set_text(str(port) + '\n' + str(state_id))
 
             if row_idx == columns[col_idx]-1:
                 # if last row of column
@@ -680,12 +686,17 @@ def plot_agents_multigen(data, settings={}, out_dir='out', filename='agents'):
     port_schema_paths = [path for path in port_schema_paths if path not in remove_paths]
     top_ports = set([path[0] for path in port_schema_paths])
 
-    # get port columns, assign subplot locations
+    # get list of states for each port
     port_rows = {port_id: [] for port_id in top_ports}
     for path in port_schema_paths:
         top_port = path[0]
         port_rows[top_port].append(path)
 
+    # sort each port by second element
+    for port_id, path_list in port_rows.items():
+        sorted_path = sorted(path_list, key=lambda x: x[1])
+        port_rows[port_id] = sorted_path
+
     highest_row = 0
     row_idx = 0
     col_idx = 0
@@ -731,7 +742,11 @@ def plot_agents_multigen(data, settings={}, out_dir='out', filename='agents'):
                     which=tick_type,
                     labelsize=tick_label_size,
                 )
-            ax.title.set_text(titles_map.get(path, path))
+            state_title = titles_map.get(path, path)
+            if isinstance(state_title, tuple):
+                # new line for each store
+                state_title = ' \n'.join(state_title)
+            ax.title.set_text(state_title)
             ax.title.set_fontsize(title_size)
             if path in ylabels_map:
                 ax.set_ylabel(ylabels_map[path], fontsize=title_size)
